@@ -58,6 +58,7 @@ static gboolean in_change = FALSE;
 
 #ifdef HAVE_XFT2
 
+#if !GTK_CHECK_VERSION (3, 0, 0)
 /*
  * Code for displaying previews of font rendering with various Xft options
  */
@@ -69,25 +70,52 @@ static void sample_size_request(GtkWidget* darea, GtkRequisition* requisition)
 	requisition->width = gdk_pixbuf_get_width(pixbuf) + 2;
 	requisition->height = gdk_pixbuf_get_height(pixbuf) + 2;
 }
+#endif
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+static void sample_draw(GtkWidget* darea, cairo_t* cr)
+#else
 static void sample_expose(GtkWidget* darea, GdkEventExpose* expose)
+#endif
 {
 	GtkAllocation allocation;
 	GdkPixbuf* pixbuf = g_object_get_data(G_OBJECT(darea), "sample-pixbuf");
+#if !GTK_CHECK_VERSION (3, 0, 0)
 	GdkWindow* window = gtk_widget_get_window(darea);
 	GtkStyle* style = gtk_widget_get_style(darea);
 	int width = gdk_pixbuf_get_width(pixbuf);
 	int height = gdk_pixbuf_get_height(pixbuf);
+#endif
 
 	gtk_widget_get_allocation (darea, &allocation);
 
+#if !GTK_CHECK_VERSION (3, 0, 0)
 	int x = (allocation.width - width) / 2;
 	int y = (allocation.height - height) / 2;
+#endif
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+	cairo_set_line_width(cr, 1);
+
+	cairo_set_source_rgb(cr, 1.0, 1.0, 1.0);
+	cairo_rectangle(cr, 0, 0, allocation.width, allocation.height);
+	cairo_stroke_preserve(cr);
+	cairo_fill(cr);
+
+	cairo_set_source_rgb(cr, 0.0, 0.0, 0.0);
+	cairo_rectangle(cr, 0, 0, allocation.width - 1, allocation.height - 1);
+	cairo_stroke_preserve(cr);
+	cairo_fill(cr);
+
+	gdk_cairo_set_source_pixbuf(cr, pixbuf, 0, 0);
+	cairo_paint(cr);
+	cairo_fill (cr);
+#else
 	gdk_draw_rectangle(window, style->white_gc, TRUE, 0, 0, allocation.width, allocation.height);
 	gdk_draw_rectangle(window, style->black_gc, FALSE, 0, 0, allocation.width - 1, allocation.height - 1);
 
 	gdk_draw_pixbuf(window, NULL, pixbuf, 0, 0, x, y, width, height, GDK_RGB_DITHER_NORMAL, 0, 0);
+#endif
 }
 
 typedef enum {
@@ -169,10 +197,18 @@ static void setup_font_sample(GtkWidget* darea, Antialiasing antialiasing, Hinti
 
 	Display* xdisplay = gdk_x11_get_default_xdisplay();
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+	Colormap xcolormap = DefaultColormap(xdisplay, 0);
+#else
 	GdkColormap* colormap = gdk_rgb_get_colormap();
 	Colormap xcolormap = GDK_COLORMAP_XCOLORMAP(colormap);
+#endif
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+	GdkVisual* visual = gdk_visual_get_system ();
+#else
 	GdkVisual* visual = gdk_colormap_get_visual(colormap);
+#endif
 	Visual* xvisual = GDK_VISUAL_XVISUAL(visual);
 
 	FcPattern* pattern;
@@ -180,7 +216,9 @@ static void setup_font_sample(GtkWidget* darea, Antialiasing antialiasing, Hinti
 	XftFont* font2;
 	XGlyphInfo extents1 = { 0 };
 	XGlyphInfo extents2 = { 0 };
+#if !GTK_CHECK_VERSION (3, 0, 0)
 	GdkPixmap* pixmap;
+#endif
 	XftDraw* draw;
 	GdkPixbuf* tmp_pixbuf;
 	GdkPixbuf* pixbuf;
@@ -225,9 +263,15 @@ static void setup_font_sample(GtkWidget* darea, Antialiasing antialiasing, Hinti
 	width = extents1.xOff + extents2.xOff + 4;
 	height = ascent + descent + 2;
 
+#if !GTK_CHECK_VERSION (3, 0, 0)
 	pixmap = gdk_pixmap_new (NULL, width, height, visual->depth);
+#endif
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+	draw = XftDrawCreate (xdisplay, GDK_WINDOW_XID (gdk_screen_get_root_window (gdk_screen_get_default ())), xvisual, xcolormap);
+#else
 	draw = XftDrawCreate (xdisplay, GDK_DRAWABLE_XID (pixmap), xvisual, xcolormap);
+#endif
 
 	rendcolor.red = 0;
 	rendcolor.green = 0;
@@ -266,16 +310,27 @@ static void setup_font_sample(GtkWidget* darea, Antialiasing antialiasing, Hinti
 		XftFontClose(xdisplay, font2);
 	}
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+	tmp_pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE,8, width, height);
+#else
 	tmp_pixbuf = gdk_pixbuf_get_from_drawable(NULL, pixmap, colormap, 0, 0, 0, 0, width, height);
+#endif
 	pixbuf = gdk_pixbuf_scale_simple(tmp_pixbuf, 1 * width, 1 * height, GDK_INTERP_TILES);
 
+#if !GTK_CHECK_VERSION (3, 0, 0)
 	g_object_unref(pixmap);
+#endif
 	g_object_unref(tmp_pixbuf);
 
 	g_object_set_data_full(G_OBJECT(darea), "sample-pixbuf", pixbuf, (GDestroyNotify) g_object_unref);
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+	gtk_widget_set_size_request  (GTK_WIDGET(darea), width + 2, height + 2);
+	g_signal_connect(darea, "draw", G_CALLBACK(sample_draw), NULL);
+#else
 	g_signal_connect(darea, "size_request", G_CALLBACK(sample_size_request), NULL);
 	g_signal_connect(darea, "expose_event", G_CALLBACK(sample_expose), NULL);
+#endif
 }
 
 /*
@@ -455,7 +510,7 @@ enum_group_create (GSettings           *settings,
 
   group = g_new (EnumGroup, 1);
 
-  group->settings = settings;
+  group->settings = g_object_ref (settings);
   group->settings_key = g_strdup (settings_key);
   group->items = NULL;
 
@@ -493,8 +548,8 @@ enum_group_create (GSettings           *settings,
 static void
 enum_group_destroy (EnumGroup *group)
 {
-  group->settings = NULL;
   g_signal_handler_disconnect (group->settings, group->settings_signal_id);
+  g_clear_object (&group->settings);
   group->settings_signal_id = 0;
   g_free (group->settings_key);
 
@@ -711,11 +766,15 @@ void font_init(AppearanceData* data)
 			 G_SETTINGS_BIND_DEFAULT);
 
 	widget = appearance_capplet_get_widget (data, "desktop_font");
-	g_settings_bind (data->caja_settings,
-			 DESKTOP_FONT_KEY,
-			 G_OBJECT (widget),
-			 "font-name",
-			 G_SETTINGS_BIND_DEFAULT);
+
+	if (data->caja_settings)
+		g_settings_bind (data->caja_settings,
+				 DESKTOP_FONT_KEY,
+				 G_OBJECT (widget),
+				 "font-name",
+				 G_SETTINGS_BIND_DEFAULT);
+	else
+		gtk_widget_set_sensitive (widget, FALSE);
 
 	widget = appearance_capplet_get_widget (data, "window_title_font");
 	g_settings_bind (data->marco_settings,
