@@ -28,7 +28,6 @@
 #include <gdk/gdkkeysyms.h>
 #if GTK_CHECK_VERSION (3, 0, 0)
 #include <gdk/gdkkeysyms-compat.h>
-#define gtk_widget_hide_all gtk_widget_hide
 #endif
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -112,7 +111,7 @@ show_shell (AppShellData * app_data)
 {
 	gtk_widget_show_all (app_data->main_app);
 	if (!app_data->static_actions)
-		gtk_widget_hide_all (app_data->actions_section);  /* don't show unless a launcher is selected */
+		gtk_widget_hide (app_data->actions_section);  /* don't show unless a launcher is selected */
 
 	if (app_data->main_app_window_shown_once)
 		gtk_window_move (GTK_WINDOW (app_data->main_app),
@@ -132,7 +131,9 @@ create_main_window (AppShellData * app_data, const gchar * app_name, const gchar
 	app_data->main_app = main_app;
 	gtk_widget_set_name (main_app, app_name);
 	gtk_window_set_title (GTK_WINDOW (main_app), title);
-	/* gtk_window_set_default_size(GTK_WINDOW(main_app), width, height); */
+#if GTK_CHECK_VERSION (3, 0, 0)
+	gtk_window_set_default_size(GTK_WINDOW(main_app), width, height);
+#endif
 	gtk_window_set_icon_name (GTK_WINDOW (main_app), window_icon);
 	gtk_container_add (GTK_CONTAINER (main_app), app_data->shell);
 
@@ -379,7 +380,7 @@ relayout_shell (AppShellData * app_data)
 
 	gtk_widget_show_all (shell);
 	if (!app_data->static_actions && !app_data->last_clicked_launcher)
-		gtk_widget_hide_all (app_data->actions_section);  /* don't show unless a launcher is selected */
+		gtk_widget_hide (app_data->actions_section);  /* don't show unless a launcher is selected */
 }
 
 static GtkWidget *
@@ -1183,6 +1184,12 @@ generate_new_apps (AppShellData * app_data)
 				{
 					g_object_unref (file);
 					g_warning ("Cant get vfs info for %s\n", uri);
+					if (new_apps_category) {
+						g_free (new_apps_category->category);
+						g_free (new_apps_category);
+					}
+					g_free (all_apps_file_name);
+					g_strfreev (all_apps_split);
 					return;
 				}
 				filetime = (long) g_file_info_get_attribute_uint64 (info,
